@@ -20,18 +20,9 @@
 #include "khmthemefactory.h"
 #include <QDebug>
 
-KHMThemeFactory::KHMThemeFactory()
-{
-}
-
 bool KHMThemeFactory::addTheme(const QString &themeFile)
 {
     QFile file (themeFile);
-    QDomDocument tree(QStringLiteral("KHangManTheme")); //do we need it?
-    QDomElement root;
-    QDomNode themeNode;
-    QDomElement themeElement;
-
     if (!file.exists()) {
         qDebug() << "Themes file doesn't exist";
         return false;
@@ -42,6 +33,7 @@ bool KHMThemeFactory::addTheme(const QString &themeFile)
         return false;
     }
 
+    QDomDocument tree(QStringLiteral("KHangManTheme")); //do we need it?
     if (!tree.setContent(&file)) {
         file.close();
         qDebug()<<"Can't set content for theme file";
@@ -49,33 +41,28 @@ bool KHMThemeFactory::addTheme(const QString &themeFile)
     }
 
     file.close();
-    root=tree.documentElement();
+    const QDomElement root=tree.documentElement();
 
     if (!checkTheme(root, QStringLiteral("1"))) {
         qDebug()<<"Incompatible version of theme loaded";
         return false;
     }
 
-    QString themeVersion=root.attribute(QStringLiteral("version"));
-    themeNode=root.firstChild();
-
-    do {
+    const QString themeVersion=root.attribute(QStringLiteral("version"));
+    for (QDomNode themeNode=root.firstChild(); !themeNode.isNull(); themeNode=themeNode.nextSibling()) {
         doTheme(themeNode.toElement(), themeVersion);
-        themeNode=themeNode.nextSibling();
-    } while (!themeNode.isNull());
+    }
     return true;
 }
 
 void KHMThemeFactory::walkDirectory(const QDir &dir)       //unused! (but works)
 {
-    QFileInfoList xmlFilesList;
-    QStringList allowedExtenstion(QStringLiteral("*.xml"));
-
     if (dir.exists()) {
-        xmlFilesList=dir.entryInfoList(allowedExtenstion, QDir::Files);
+        const QStringList allowedExtenstion(QStringLiteral("*.xml"));
+        const QFileInfoList xmlFilesList=dir.entryInfoList(allowedExtenstion, QDir::Files);
 
-        for (QFileInfoList::iterator i=xmlFilesList.begin(); i!=xmlFilesList.end(); ++i) {
-            addTheme(i->absoluteFilePath());
+        for (const auto &file : xmlFilesList) {
+            addTheme(file.absoluteFilePath());
         }
     }
 }
@@ -85,37 +72,35 @@ int KHMThemeFactory::getQty() const
     return themesList.size();
 }
 
-QStringList KHMThemeFactory::getNames()
+QStringList KHMThemeFactory::getNames() const
 {
     QStringList list;
-    for (int i=0; i<themesList.size(); i++) {
-        list.append(themesList[i].name());
+    for (const auto &theme : themesList) {
+        list.append(theme.name());
     }
-
     return list;
 }
 
-QStringList KHMThemeFactory::themeList()
+QStringList KHMThemeFactory::themeList() const
 {
     QStringList list;
-    for (int i=0; i<themesList.size(); i++) {
-        list.append(themesList[i].uiName());
+    for (const auto &theme : themesList) {
+        list.append(theme.uiName());
     }
-
     return list;
 }
 
-KHMTheme * KHMThemeFactory::buildTheme (int id)
+const KHMTheme * KHMThemeFactory::getTheme(int id) const
 {
-    if (id >= 0 && id < themesList.size())
-        return new KHMTheme(themesList[id]);
-    else
-        return nullptr;
+    if (id >= 0 && id < themesList.size()) {
+        return &themesList[id];
+    }
+    return nullptr;
 }
 
 QRect KHMThemeFactory::makeRect(const QDomElement &element, const QString &propertyName)
 {
-    QDomElement rect=element.firstChildElement(propertyName);
+    const QDomElement rect=element.firstChildElement(propertyName);
 
     return QRect(
         (int)(rect.attribute(QStringLiteral("xratio")).toDouble()*10000),
@@ -127,50 +112,44 @@ QRect KHMThemeFactory::makeRect(const QDomElement &element, const QString &prope
 
 QColor KHMThemeFactory::getColor(const QDomElement &element, const QString &propertyName)
 {
-    QDomElement color=element.firstChildElement(propertyName);
+    const QDomElement color=element.firstChildElement(propertyName);
 
     return QColor ( color.attribute(QStringLiteral("r")).toInt(), color.attribute(QStringLiteral("g")).toInt(), color.attribute(QStringLiteral("b")).toInt());
 }
 
 bool KHMThemeFactory::checkTheme(const QDomElement &root, const QString &themeVersion)
 {
-    QString rootName=root.tagName();
+    const QString rootName=root.tagName();
 
-    return (rootName.compare(QLatin1String("KHangManThemes"))==0)	&&	(themeVersion.compare(root.attribute(QStringLiteral("version")))==0);
+    return (rootName==QLatin1String("KHangManThemes")) && (themeVersion==root.attribute(QStringLiteral("version")));
 }
 
 void KHMThemeFactory::doTheme(const QDomElement &theme, const QString &version)   //fetch all the properties from .xml and stick it together
 //"theme" means <theme></theme> section
 {
-    QDomElement coords=theme.firstChildElement(QStringLiteral("coords"));
-
     //Names of elements are camelCase, but
     //attributes are always lowercase
 
-    QString name=theme.attribute(QStringLiteral("name"));
-    QString uiName=theme.attribute(QStringLiteral("uiname"));
-    QString svgFileName=theme.attribute(QStringLiteral("svgfilename"));
-    QString author=theme.attribute(QStringLiteral("author"));
-    QString themeVersion=version;
+    const QString name=theme.attribute(QStringLiteral("name"));
+    const QString uiName=theme.attribute(QStringLiteral("uiname"));
+    const QString svgFileName=theme.attribute(QStringLiteral("svgfilename"));
+    const QString author=theme.attribute(QStringLiteral("author"));
 
-    QColor letterColor=getColor(theme.firstChildElement(QStringLiteral("colors")), QStringLiteral("letterColor"));
-    QColor guessButtonTextColor=getColor(theme.firstChildElement(QStringLiteral("colors")), QStringLiteral("guessButtonTextColor"));
-    QColor guessButtonColor=getColor(theme.firstChildElement(QStringLiteral("colors")), QStringLiteral("guessButtonColor"));
-    QColor guessButtonHoverColor=getColor(theme.firstChildElement(QStringLiteral("colors")), QStringLiteral("guessButtonHoverColor"));
-    QColor letterInputTextColor=getColor(theme.firstChildElement(QStringLiteral("colors")), QStringLiteral("letterInputTextColor"));
+    const QDomElement colors=theme.firstChildElement(QStringLiteral("colors"));
+    const QColor letterColor=getColor(colors, QStringLiteral("letterColor"));
+    const QColor guessButtonTextColor=getColor(colors, QStringLiteral("guessButtonTextColor"));
+    const QColor guessButtonColor=getColor(colors, QStringLiteral("guessButtonColor"));
+    const QColor guessButtonHoverColor=getColor(colors, QStringLiteral("guessButtonHoverColor"));
+    const QColor letterInputTextColor=getColor(colors, QStringLiteral("letterInputTextColor"));
 
-    QRect wordRect=makeRect(theme.firstChildElement(QStringLiteral("coords")), QStringLiteral("wordRect"));
-    QRect hintRect=makeRect(theme.firstChildElement(QStringLiteral("coords")), QStringLiteral("hintRect"));
-    QRect kRect=makeRect(theme.firstChildElement(QStringLiteral("coords")), QStringLiteral("kRect"));
+    const QDomElement coords=theme.firstChildElement(QStringLiteral("coords"));
+    const QRect wordRect=makeRect(coords, QStringLiteral("wordRect"));
+    const QRect hintRect=makeRect(coords, QStringLiteral("hintRect"));
+    const QRect kRect=makeRect(coords, QStringLiteral("kRect"));
 
-    QDomElement wordPos = theme.firstChildElement(QStringLiteral("coords")).firstChildElement(QStringLiteral("goodWordPos"));
-    QPoint goodWordPos = QPoint(	wordPos.attribute(QStringLiteral("wratio")).toDouble()*10000, wordPos.attribute(QStringLiteral("hratio")).toDouble()*10000	);
+    const QDomElement wordPos = coords.firstChildElement(QStringLiteral("goodWordPos"));
+    const QPoint goodWordPos = QPoint(	wordPos.attribute(QStringLiteral("wratio")).toDouble()*10000, wordPos.attribute(QStringLiteral("hratio")).toDouble()*10000	);
 
-    KHMTheme * newTheme = new KHMTheme (name, uiName, svgFileName, author, themeVersion, wordRect, hintRect, kRect, letterColor, guessButtonTextColor, guessButtonColor, guessButtonHoverColor, letterInputTextColor, goodWordPos);
-    themesList.append(*newTheme);
-}
-
-KHMThemeFactory::~KHMThemeFactory()
-{
-    themesList.clear();
+    const KHMTheme newTheme (name, uiName, svgFileName, author, version, wordRect, hintRect, kRect, letterColor, guessButtonTextColor, guessButtonColor, guessButtonHoverColor, letterInputTextColor, goodWordPos);
+    themesList.append(newTheme);
 }
